@@ -39,16 +39,14 @@ public:
     QSize framebufferSize() override; // returns the size of the remote view
     QSize sizeHint() const override; // returns the suggested size
 
-    // functions regarding the connection
-    void startQuitting() override; // start closing the connection
     bool isQuitting() override; // are we currently closing the connection?
-    bool start() override; // open a connection
 
     HostPreferences *hostPreferences() override;
 
     bool supportsScaling() const override;
     bool supportsLocalCursor() const override;
     bool supportsViewOnly() const override;
+    bool supportsClipboardSharing() const override;
 
     void showLocalCursor(LocalCursorState state) override;
     bool scaling() const override;
@@ -67,6 +65,9 @@ public Q_SLOTS:
     void setRemoteCursor(const QCursor cursor);
 
 protected:
+    bool startConnection() override;
+    void startQuittingConnection() override;
+
     QSize initialSize();
 
     void paintEvent(QPaintEvent *event) override;
@@ -76,7 +77,7 @@ protected:
     void handleLocalClipboardChanged(const QMimeData *data) override;
 
 private:
-    void onRectangleUpdated(const QRect &rect);
+    void onRectangleUpdated(const QRect &remoteRect, const QSize &remoteSize);
     void handleError(unsigned int error);
 
     QString m_name;
@@ -89,8 +90,6 @@ private:
     std::unique_ptr<RdpHostPreferences> m_hostPreferences;
     std::unique_ptr<RdpSession> m_session;
 
-    QRect m_pendingRectangle;
-    QImage m_pendingData;
     QCursor m_remoteCursor;
 };
 
